/* individual-properties.c generated by valac 0.26.2.1-1f25, the Vala compiler
 * generated from individual-properties.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks.h>
#include <folks/folks-telepathy.h>
#include <telepathy-glib/telepathy-glib.h>
#include <tp-test-contactlist.h>
#include <gio/gio.h>


#define TYPE_INDIVIDUAL_PROPERTIES_TESTS (individual_properties_tests_get_type ())
#define INDIVIDUAL_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTests))
#define INDIVIDUAL_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsClass))
#define IS_INDIVIDUAL_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS))
#define IS_INDIVIDUAL_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INDIVIDUAL_PROPERTIES_TESTS))
#define INDIVIDUAL_PROPERTIES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsClass))

typedef struct _IndividualPropertiesTests IndividualPropertiesTests;
typedef struct _IndividualPropertiesTestsClass IndividualPropertiesTestsClass;
typedef struct _IndividualPropertiesTestsPrivate IndividualPropertiesTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _IndividualPropertiesTests {
	TpfTestTestCase parent_instance;
	IndividualPropertiesTestsPrivate * priv;
};

struct _IndividualPropertiesTestsClass {
	TpfTestTestCaseClass parent_class;
};

struct _IndividualPropertiesTestsPrivate {
	GeeHashSet* _changes_pending;
	gchar* olivier_sha1;
};

struct _Block1Data {
	int _ref_count_;
	IndividualPropertiesTests* self;
	gboolean alias_notified;
};

struct _Block2Data {
	int _ref_count_;
	Block1Data * _data1_;
	gchar* new_alias;
};

struct _Block3Data {
	int _ref_count_;
	IndividualPropertiesTests* self;
	gboolean alias_notified;
};

struct _Block4Data {
	int _ref_count_;
	Block3Data * _data3_;
	gchar* new_alias;
};

struct _Block5Data {
	int _ref_count_;
	IndividualPropertiesTests* self;
	GDateTime* new_birthday;
	FolksEmailFieldDetails* new_email_fd;
	FolksPhoneFieldDetails* new_phone_fd;
	FolksUrlFieldDetails* new_url_fd;
	gchar* new_full_name;
	gpointer _async_data_;
};

struct _IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	IndividualPropertiesTests* self;
	GeeMultiMap* changes;
	Block5Data* _data5_;
	GeeCollection* added;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_;
	GTimeVal timeval;
	GTimeVal _tmp4_;
	GDateTime* _tmp5_;
	GDateTime* _tmp6_;
	FolksEmailFieldDetails* _tmp7_;
	FolksEmailFieldDetails* _tmp8_;
	FolksPhoneFieldDetails* _tmp9_;
	FolksPhoneFieldDetails* _tmp10_;
	FolksUrlFieldDetails* _tmp11_;
	FolksUrlFieldDetails* _tmp12_;
	gchar* _tmp13_;
	GeeIterator* _i_it;
	GeeCollection* _tmp14_;
	GeeIterator* _tmp15_;
	GeeIterator* _tmp16_;
	gboolean _tmp17_;
	FolksIndividual* i;
	GeeIterator* _tmp18_;
	gpointer _tmp19_;
	FolksIndividual* _tmp20_;
	gboolean _tmp21_;
	FolksIndividual* _tmp22_;
	GDateTime* _tmp23_;
	GDateTime* _tmp24_;
	GDateTime* _tmp25_;
	FolksIndividual* _tmp26_;
	GDateTime* _tmp27_;
	GDateTime* _tmp28_;
	gboolean _tmp29_;
	FolksIndividual* _tmp30_;
	GeeSet* _tmp31_;
	GeeSet* _tmp32_;
	FolksEmailFieldDetails* _tmp33_;
	gboolean _tmp34_;
	const gchar* _tmp35_;
	FolksIndividual* _tmp36_;
	const gchar* _tmp37_;
	const gchar* _tmp38_;
	FolksIndividual* _tmp39_;
	GeeSet* _tmp40_;
	GeeSet* _tmp41_;
	FolksPhoneFieldDetails* _tmp42_;
	gboolean _tmp43_;
	FolksIndividual* _tmp44_;
	GeeSet* _tmp45_;
	GeeSet* _tmp46_;
	FolksUrlFieldDetails* _tmp47_;
	gboolean _tmp48_;
	FolksIndividual* _tmp49_;
	FolksIndividual* _tmp50_;
	FolksIndividual* _tmp51_;
	FolksIndividual* _tmp52_;
	FolksIndividual* _tmp53_;
	FolksPersona* persona;
	GeeIterator* _p_it;
	FolksIndividual* _tmp54_;
	GeeSet* _tmp55_;
	GeeSet* _tmp56_;
	GeeIterator* _tmp57_;
	GeeIterator* _tmp58_;
	gboolean _tmp59_;
	FolksPersona* p;
	GeeIterator* _tmp60_;
	gpointer _tmp61_;
	FolksPersona* _tmp62_;
	FolksPersona* _tmp63_;
	FolksPersona* _tmp64_;
	GeeHashSet* emails;
	GeeHashSet* _tmp65_;
	GeeHashSet* _tmp66_;
	FolksEmailFieldDetails* _tmp67_;
	GeeHashSet* phones;
	GeeHashSet* _tmp68_;
	GeeHashSet* _tmp69_;
	FolksPhoneFieldDetails* _tmp70_;
	GeeHashSet* urls;
	GeeHashSet* _tmp71_;
	GeeHashSet* _tmp72_;
	FolksUrlFieldDetails* _tmp73_;
	gint uncaught_errors;
	FolksIndividual* _tmp74_;
	gboolean _tmp75_;
	gboolean _tmp76_;
	gint _tmp77_;
	FolksPersona* _tmp78_;
	GDateTime* _tmp79_;
	GError* e_birthday;
	FolksIndividual* _tmp80_;
	gboolean _tmp81_;
	gboolean _tmp82_;
	gint _tmp83_;
	FolksIndividual* _tmp84_;
	gboolean _tmp85_;
	gboolean _tmp86_;
	gint _tmp87_;
	FolksPersona* _tmp88_;
	GeeHashSet* _tmp89_;
	GError* e0;
	FolksIndividual* _tmp90_;
	gboolean _tmp91_;
	gboolean _tmp92_;
	gint _tmp93_;
	FolksIndividual* _tmp94_;
	gboolean _tmp95_;
	gboolean _tmp96_;
	gint _tmp97_;
	FolksPersona* _tmp98_;
	const gchar* _tmp99_;
	GError* e1;
	FolksIndividual* _tmp100_;
	gboolean _tmp101_;
	gboolean _tmp102_;
	gint _tmp103_;
	FolksIndividual* _tmp104_;
	gboolean _tmp105_;
	gboolean _tmp106_;
	gint _tmp107_;
	FolksPersona* _tmp108_;
	GeeHashSet* _tmp109_;
	GError* e2;
	FolksIndividual* _tmp110_;
	gboolean _tmp111_;
	gboolean _tmp112_;
	gint _tmp113_;
	FolksIndividual* _tmp114_;
	gboolean _tmp115_;
	gboolean _tmp116_;
	gint _tmp117_;
	FolksPersona* _tmp118_;
	GeeHashSet* _tmp119_;
	GError* e3;
	FolksIndividual* _tmp120_;
	gboolean _tmp121_;
	gboolean _tmp122_;
	gint _tmp123_;
	FolksIndividual* _tmp124_;
	gboolean _tmp125_;
	gboolean _tmp126_;
	gint _tmp127_;
	GeeSet* _tmp128_;
	gint _tmp129_;
	gint _tmp130_;
	GeeIterator* _r_it;
	GeeSet* _tmp131_;
	GeeIterator* _tmp132_;
	GeeIterator* _tmp133_;
	gboolean _tmp134_;
	FolksIndividual* r;
	GeeIterator* _tmp135_;
	gpointer _tmp136_;
	FolksIndividual* _tmp137_;
	GError * _inner_error_;
};


static gpointer individual_properties_tests_parent_class = NULL;
static gchar* individual_properties_tests_iid_prefix;
static gchar* individual_properties_tests_iid_prefix = NULL;

GType individual_properties_tests_get_type (void) G_GNUC_CONST;
#define INDIVIDUAL_PROPERTIES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsPrivate))
enum  {
	INDIVIDUAL_PROPERTIES_TESTS_DUMMY_PROPERTY
};
IndividualPropertiesTests* individual_properties_tests_new (void);
IndividualPropertiesTests* individual_properties_tests_construct (GType object_type);
void individual_properties_tests_test_individual_properties (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_alias_through_test_cm (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_contact_info (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method (gpointer self);
static void individual_properties_tests_real_set_up (FolksTestCase* base);
static void individual_properties_tests_real_tear_down (FolksTestCase* base);
static void __lambda4_ (IndividualPropertiesTests* self, GeeMultiMap* changes);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void ___lambda4__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda5_ (Block1Data* _data1_, GeeMultiMap* changes);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void ____lambda6_ (Block2Data* _data2_, GObject* s, GParamSpec* p);
static void _____lambda6__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ___lambda5__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda7_ (Block3Data* _data3_, GeeMultiMap* changes);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void ____lambda8_ (Block4Data* _data4_, GObject* s, GParamSpec* p);
static void _____lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda9_ (IndividualPropertiesTests* self, GeeMultiMap* changes);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added (IndividualPropertiesTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_finish (IndividualPropertiesTests* self, GAsyncResult* _res_);
static void ___lambda9__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free (gpointer _data);
static gboolean _individual_properties_tests_change_contact_info_aggregator_individuals_added_co (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void ____lambda10_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda11_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda12_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda13_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda13__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda14_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void individual_properties_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _individual_properties_tests_test_individual_properties_folks_test_case_test_method (gpointer self) {
#line 40 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties ((IndividualPropertiesTests*) self);
#line 349 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method (gpointer self) {
#line 42 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_alias_through_tp_backend ((IndividualPropertiesTests*) self);
#line 356 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method (gpointer self) {
#line 44 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_alias_through_test_cm ((IndividualPropertiesTests*) self);
#line 363 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method (gpointer self) {
#line 46 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_contact_info ((IndividualPropertiesTests*) self);
#line 370 "individual-properties.c"
}


IndividualPropertiesTests* individual_properties_tests_construct (GType object_type) {
	IndividualPropertiesTests * self = NULL;
#line 38 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) tpf_test_test_case_construct (object_type, "IndividualProperties");
#line 40 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties", _individual_properties_tests_test_individual_properties_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 42 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change alias through tp backend", _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 44 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change alias through test cm", _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 46 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change contact info", _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method, g_object_ref (self), g_object_unref);
#line 36 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return self;
#line 388 "individual-properties.c"
}


IndividualPropertiesTests* individual_properties_tests_new (void) {
#line 36 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return individual_properties_tests_construct (TYPE_INDIVIDUAL_PROPERTIES_TESTS);
#line 395 "individual-properties.c"
}


static void individual_properties_tests_real_set_up (FolksTestCase* base) {
	IndividualPropertiesTests * self;
	GeeHashSet* _tmp0_ = NULL;
#line 50 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) base;
#line 52 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (individual_properties_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TPF_TEST_TYPE_TEST_CASE, TpfTestTestCase));
#line 54 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 54 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 54 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = _tmp0_;
#line 412 "individual-properties.c"
}


static void individual_properties_tests_real_tear_down (FolksTestCase* base) {
	IndividualPropertiesTests * self;
#line 57 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) base;
#line 59 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 59 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = NULL;
#line 61 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (individual_properties_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TPF_TEST_TYPE_TEST_CASE, TpfTestTestCase));
#line 426 "individual-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 433 "individual-properties.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	for (i = 0; i < stack_length; i++) {
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			return TRUE;
#line 445 "individual-properties.c"
		}
	}
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return FALSE;
#line 450 "individual-properties.c"
}


static void __lambda4_ (IndividualPropertiesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp171_ = NULL;
	gint _tmp172_ = 0;
	gint _tmp173_ = 0;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 72 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 72 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 72 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 73 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 73 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 73 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 478 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp4_ = added;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp5_;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 491 "individual-properties.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp6_ = _i_it;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp7_) {
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 509 "individual-properties.c"
			}
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = _i_it;
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp9_;
#line 77 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = i;
#line 77 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = _tmp12_;
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (_tmp13_) {
#line 529 "individual-properties.c"
				FolksIndividual* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				FolksIndividual* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				FolksIndividual* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
				FolksIndividual* _tmp23_ = NULL;
				FolksPresenceType _tmp24_ = 0;
				FolksPresenceType _tmp25_ = 0;
				FolksIndividual* _tmp26_ = NULL;
				gboolean _tmp27_ = FALSE;
				FolksIndividual* _tmp28_ = NULL;
				GeeSet* _tmp29_ = NULL;
				GeeSet* _tmp30_ = NULL;
				gint _tmp31_ = 0;
				gint _tmp32_ = 0;
				TpfPersona* tpf_persona = NULL;
				TpfPersona* _tmp44_ = NULL;
				TpfPersona* _tmp45_ = NULL;
				gchar** _tmp46_ = NULL;
				gint _tmp46__length1 = 0;
				gchar** _tmp47_ = NULL;
				gint _tmp47__length1 = 0;
				TpfPersona* _tmp48_ = NULL;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				gchar** _tmp50_ = NULL;
				gint _tmp50__length1 = 0;
				TpfPersona* _tmp51_ = NULL;
				gchar** _tmp52_ = NULL;
				gint _tmp52__length1 = 0;
				gchar** _tmp53_ = NULL;
				gint _tmp53__length1 = 0;
				TpfPersona* _tmp54_ = NULL;
				gboolean _tmp55_ = FALSE;
				gboolean _tmp56_ = FALSE;
				TpfPersona* _tmp57_ = NULL;
				gchar** _tmp58_ = NULL;
				gint _tmp58__length1 = 0;
				gchar** _tmp59_ = NULL;
				gint _tmp59__length1 = 0;
				TpfPersona* _tmp60_ = NULL;
				gchar** _tmp61_ = NULL;
				gint _tmp61__length1 = 0;
				gchar** _tmp62_ = NULL;
				gint _tmp62__length1 = 0;
				TpfPersona* _tmp63_ = NULL;
				gchar** _tmp64_ = NULL;
				gint _tmp64__length1 = 0;
				gchar** _tmp65_ = NULL;
				gint _tmp65__length1 = 0;
				TpfPersona* _tmp66_ = NULL;
				gchar** _tmp67_ = NULL;
				gint _tmp67__length1 = 0;
				gchar** _tmp68_ = NULL;
				gint _tmp68__length1 = 0;
				TpfPersona* _tmp69_ = NULL;
				gchar** _tmp70_ = NULL;
				gint _tmp70__length1 = 0;
				gchar** _tmp71_ = NULL;
				gint _tmp71__length1 = 0;
				FolksIndividual* _tmp72_ = NULL;
				const gchar* _tmp73_ = NULL;
				const gchar* _tmp74_ = NULL;
				FolksIndividual* _tmp75_ = NULL;
				GeeSet* _tmp76_ = NULL;
				GeeSet* _tmp77_ = NULL;
				gint _tmp78_ = 0;
				gint _tmp79_ = 0;
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp14_ = i;
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp15_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp14_);
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp16_ = _tmp15_;
#line 83 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp16_, "me@example.com") == 0, "i.alias == \"me@example.com\"");
#line 84 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp17_ = i;
#line 84 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp18_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) _tmp17_);
#line 84 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp19_ = _tmp18_;
#line 84 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp19_, "") == 0, "i.presence_message == \"\"");
#line 85 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 85 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) _tmp20_);
#line 85 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 85 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp22_, "available") == 0, "i.presence_status == \"available\"");
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = i;
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp24_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp23_);
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp25_ = _tmp24_;
#line 86 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp25_ == FOLKS_PRESENCE_TYPE_AVAILABLE, "i.presence_type == PresenceType.AVAILABLE");
#line 87 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp26_ = i;
#line 87 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp27_ = folks_presence_details_is_online (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, FOLKS_TYPE_PRESENCE_DETAILS, FolksPresenceDetails));
#line 87 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp27_ == TRUE, "((PresenceDetails) i).is_online () == true");
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp28_ = i;
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp29_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp28_);
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp30_ = _tmp29_;
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp32_ = _tmp31_;
#line 90 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp32_ == 0, "i.groups.size == 0");
#line 93 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				tpf_persona = NULL;
#line 654 "individual-properties.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp33_ = NULL;
					GeeSet* _tmp34_ = NULL;
					GeeSet* _tmp35_ = NULL;
					GeeIterator* _tmp36_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp33_ = i;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp35_ = _tmp34_;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_p_it = _tmp36_;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					while (TRUE) {
#line 673 "individual-properties.c"
						GeeIterator* _tmp37_ = NULL;
						gboolean _tmp38_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp39_ = NULL;
						gpointer _tmp40_ = NULL;
						FolksPersona* _tmp41_ = NULL;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp37_ = _p_it;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp38_ = gee_iterator_next (_tmp37_);
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						if (!_tmp38_) {
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							break;
#line 688 "individual-properties.c"
						}
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp39_ = _p_it;
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp40_ = gee_iterator_get (_tmp39_);
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						p = (FolksPersona*) _tmp40_;
#line 96 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp41_ = p;
#line 96 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, TPF_TYPE_PERSONA)) {
#line 700 "individual-properties.c"
							FolksPersona* _tmp42_ = NULL;
							TpfPersona* _tmp43_ = NULL;
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp42_ = p;
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp43_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, TPF_TYPE_PERSONA) ? ((TpfPersona*) _tmp42_) : NULL);
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (tpf_persona);
#line 98 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							tpf_persona = _tmp43_;
#line 99 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (p);
#line 99 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							break;
#line 715 "individual-properties.c"
						}
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_g_object_unref0 (p);
#line 719 "individual-properties.c"
					}
#line 94 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_p_it);
#line 723 "individual-properties.c"
				}
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp44_ = tpf_persona;
#line 102 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp44_ != NULL, "tpf_persona != null");
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp45_ = tpf_persona;
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp46_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp45_, &_tmp46__length1);
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp47_ = _tmp46_;
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp47__length1 = _tmp46__length1;
#line 103 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp47_, _tmp47__length1, "alias"), "\"alias\" in tpf_persona.writeable_properties");
#line 105 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp48_ = tpf_persona;
#line 105 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp49_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp48_, &_tmp49__length1);
#line 105 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp50_ = _tmp49_;
#line 105 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp50__length1 = _tmp49__length1;
#line 105 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (!_vala_string_array_contains (_tmp50_, _tmp50__length1, "is-favourite"), "!(\"is-favourite\"                        in tpf_persona.writeable_properties)");
#line 107 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp51_ = tpf_persona;
#line 107 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp52_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp51_, &_tmp52__length1);
#line 107 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp53_ = _tmp52_;
#line 107 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp53__length1 = _tmp52__length1;
#line 107 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp53_, _tmp53__length1, "groups"), "\"groups\" in tpf_persona.writeable_properties");
#line 109 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp54_ = tpf_persona;
#line 109 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp55_ = folks_persona_get_is_user ((FolksPersona*) _tmp54_);
#line 109 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp56_ = _tmp55_;
#line 109 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp56_, "tpf_persona.is_user");
#line 110 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp57_ = tpf_persona;
#line 110 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp58_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp57_, &_tmp58__length1);
#line 110 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp59_ = _tmp58_;
#line 110 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp59__length1 = _tmp58__length1;
#line 110 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp59_, _tmp59__length1, "birthday"), "\"birthday\" in tpf_persona.writeable_properties");
#line 111 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp60_ = tpf_persona;
#line 111 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp61_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp60_, &_tmp61__length1);
#line 111 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp62_ = _tmp61_;
#line 111 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp62__length1 = _tmp61__length1;
#line 111 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp62_, _tmp62__length1, "email-addresses"), "\"email-addresses\" in tpf_persona.writeable_properties");
#line 113 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp63_ = tpf_persona;
#line 113 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp64_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp63_, &_tmp64__length1);
#line 113 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp65_ = _tmp64_;
#line 113 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp65__length1 = _tmp64__length1;
#line 113 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp65_, _tmp65__length1, "full-name"), "\"full-name\" in tpf_persona.writeable_properties");
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp66_ = tpf_persona;
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp67_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp66_, &_tmp67__length1);
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp68_ = _tmp67_;
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp68__length1 = _tmp67__length1;
#line 114 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp68_, _tmp68__length1, "phone-numbers"), "\"phone-numbers\" in tpf_persona.writeable_properties");
#line 116 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp69_ = tpf_persona;
#line 116 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp70_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp69_, &_tmp70__length1);
#line 116 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp71_ = _tmp70_;
#line 116 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp71__length1 = _tmp70__length1;
#line 116 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp71_, _tmp71__length1, "urls"), "\"urls\" in tpf_persona.writeable_properties");
#line 119 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp72_ = i;
#line 119 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp73_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp72_);
#line 119 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp74_ = _tmp73_;
#line 119 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp74_, "") == 0, "i.full_name == \"\"");
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp75_ = i;
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp76_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp75_);
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp77_ = _tmp76_;
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp78_ = gee_collection_get_size ((GeeCollection*) _tmp77_);
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp79_ = _tmp78_;
#line 120 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp79_ == 0, "i.phone_numbers.size == 0");
#line 80 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (tpf_persona);
#line 839 "individual-properties.c"
			} else {
				FolksIndividual* _tmp80_ = NULL;
				const gchar* _tmp81_ = NULL;
				const gchar* _tmp82_ = NULL;
				const gchar* _tmp83_ = NULL;
#line 125 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp80_ = i;
#line 125 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp81_ = folks_individual_get_id (_tmp80_);
#line 125 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp82_ = _tmp81_;
#line 125 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp83_ = self->priv->olivier_sha1;
#line 125 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (g_strcmp0 (_tmp82_, _tmp83_) == 0) {
#line 855 "individual-properties.c"
					FolksIndividual* _tmp84_ = NULL;
					const gchar* _tmp85_ = NULL;
					const gchar* _tmp86_ = NULL;
					FolksIndividual* _tmp87_ = NULL;
					const gchar* _tmp88_ = NULL;
					const gchar* _tmp89_ = NULL;
					FolksIndividual* _tmp90_ = NULL;
					const gchar* _tmp91_ = NULL;
					const gchar* _tmp92_ = NULL;
					FolksIndividual* _tmp93_ = NULL;
					FolksPresenceType _tmp94_ = 0;
					FolksPresenceType _tmp95_ = 0;
					FolksIndividual* _tmp96_ = NULL;
					gboolean _tmp97_ = FALSE;
					FolksIndividual* _tmp98_ = NULL;
					GeeSet* _tmp99_ = NULL;
					GeeSet* _tmp100_ = NULL;
					gint _tmp101_ = 0;
					gint _tmp102_ = 0;
					FolksIndividual* _tmp103_ = NULL;
					GeeSet* _tmp104_ = NULL;
					GeeSet* _tmp105_ = NULL;
					gboolean _tmp106_ = FALSE;
					FolksIndividual* _tmp107_ = NULL;
					GeeSet* _tmp108_ = NULL;
					GeeSet* _tmp109_ = NULL;
					gboolean _tmp110_ = FALSE;
					TpfPersona* tpf_persona = NULL;
					TpfPersona* _tmp122_ = NULL;
					TpfPersona* _tmp123_ = NULL;
					gchar** _tmp124_ = NULL;
					gint _tmp124__length1 = 0;
					gchar** _tmp125_ = NULL;
					gint _tmp125__length1 = 0;
					TpfPersona* _tmp126_ = NULL;
					gchar** _tmp127_ = NULL;
					gint _tmp127__length1 = 0;
					gchar** _tmp128_ = NULL;
					gint _tmp128__length1 = 0;
					TpfPersona* _tmp129_ = NULL;
					gchar** _tmp130_ = NULL;
					gint _tmp130__length1 = 0;
					gchar** _tmp131_ = NULL;
					gint _tmp131__length1 = 0;
					TpfPersona* _tmp132_ = NULL;
					gboolean _tmp133_ = FALSE;
					gboolean _tmp134_ = FALSE;
					TpfPersona* _tmp135_ = NULL;
					gchar** _tmp136_ = NULL;
					gint _tmp136__length1 = 0;
					gchar** _tmp137_ = NULL;
					gint _tmp137__length1 = 0;
					TpfPersona* _tmp138_ = NULL;
					gchar** _tmp139_ = NULL;
					gint _tmp139__length1 = 0;
					gchar** _tmp140_ = NULL;
					gint _tmp140__length1 = 0;
					TpfPersona* _tmp141_ = NULL;
					gchar** _tmp142_ = NULL;
					gint _tmp142__length1 = 0;
					gchar** _tmp143_ = NULL;
					gint _tmp143__length1 = 0;
					TpfPersona* _tmp144_ = NULL;
					gchar** _tmp145_ = NULL;
					gint _tmp145__length1 = 0;
					gchar** _tmp146_ = NULL;
					gint _tmp146__length1 = 0;
					TpfPersona* _tmp147_ = NULL;
					gchar** _tmp148_ = NULL;
					gint _tmp148__length1 = 0;
					gchar** _tmp149_ = NULL;
					gint _tmp149__length1 = 0;
					FolksIndividual* _tmp150_ = NULL;
					GeeSet* _tmp151_ = NULL;
					GeeSet* _tmp152_ = NULL;
					FolksPhoneFieldDetails* _tmp153_ = NULL;
					FolksPhoneFieldDetails* _tmp154_ = NULL;
					gboolean _tmp155_ = FALSE;
					FolksIndividual* _tmp156_ = NULL;
					const gchar* _tmp157_ = NULL;
					const gchar* _tmp158_ = NULL;
					FolksIndividual* _tmp159_ = NULL;
					GeeSet* _tmp160_ = NULL;
					GeeSet* _tmp161_ = NULL;
					FolksEmailFieldDetails* _tmp162_ = NULL;
					FolksEmailFieldDetails* _tmp163_ = NULL;
					gboolean _tmp164_ = FALSE;
					FolksIndividual* _tmp165_ = NULL;
					GeeSet* _tmp166_ = NULL;
					GeeSet* _tmp167_ = NULL;
					FolksUrlFieldDetails* _tmp168_ = NULL;
					FolksUrlFieldDetails* _tmp169_ = NULL;
					gboolean _tmp170_ = FALSE;
#line 128 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp84_ = i;
#line 128 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp85_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp84_);
#line 128 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp86_ = _tmp85_;
#line 128 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp86_, "Olivier") == 0, "i.alias == \"Olivier\"");
#line 129 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp87_ = i;
#line 129 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp88_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) _tmp87_);
#line 129 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp89_ = _tmp88_;
#line 129 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp89_, "") == 0, "i.presence_message == \"\"");
#line 130 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp90_ = i;
#line 130 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp91_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) _tmp90_);
#line 130 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp92_ = _tmp91_;
#line 130 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp92_, "away") == 0, "i.presence_status == \"away\"");
#line 131 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp93_ = i;
#line 131 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp94_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp93_);
#line 131 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp95_ = _tmp94_;
#line 131 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp95_ == FOLKS_PRESENCE_TYPE_AWAY, "i.presence_type == PresenceType.AWAY");
#line 132 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp96_ = i;
#line 132 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp97_ = folks_presence_details_is_online (G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, FOLKS_TYPE_PRESENCE_DETAILS, FolksPresenceDetails));
#line 132 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp97_ == TRUE, "((PresenceDetails) i).is_online () == true");
#line 135 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp98_ = i;
#line 135 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp99_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp98_);
#line 135 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp100_ = _tmp99_;
#line 135 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp101_ = gee_collection_get_size ((GeeCollection*) _tmp100_);
#line 135 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp102_ = _tmp101_;
#line 135 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp102_ == 2, "i.groups.size == 2");
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp103_ = i;
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp104_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp103_);
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp105_ = _tmp104_;
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp106_ = gee_collection_contains ((GeeCollection*) _tmp105_, "Montreal");
#line 136 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp106_ == TRUE, "i.groups.contains (\"Montreal\") == true");
#line 137 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp107_ = i;
#line 137 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp108_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp107_);
#line 137 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp109_ = _tmp108_;
#line 137 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp110_ = gee_collection_contains ((GeeCollection*) _tmp109_, "Francophones");
#line 137 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp110_ == TRUE, "i.groups.contains (\"Francophones\") == true");
#line 140 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					tpf_persona = NULL;
#line 1021 "individual-properties.c"
					{
						GeeIterator* _p_it = NULL;
						FolksIndividual* _tmp111_ = NULL;
						GeeSet* _tmp112_ = NULL;
						GeeSet* _tmp113_ = NULL;
						GeeIterator* _tmp114_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp111_ = i;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp112_ = folks_individual_get_personas (_tmp111_);
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp113_ = _tmp112_;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_tmp114_ = gee_iterable_iterator ((GeeIterable*) _tmp113_);
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_p_it = _tmp114_;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						while (TRUE) {
#line 1040 "individual-properties.c"
							GeeIterator* _tmp115_ = NULL;
							gboolean _tmp116_ = FALSE;
							FolksPersona* p = NULL;
							GeeIterator* _tmp117_ = NULL;
							gpointer _tmp118_ = NULL;
							FolksPersona* _tmp119_ = NULL;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp115_ = _p_it;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp116_ = gee_iterator_next (_tmp115_);
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							if (!_tmp116_) {
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								break;
#line 1055 "individual-properties.c"
							}
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp117_ = _p_it;
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp118_ = gee_iterator_get (_tmp117_);
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							p = (FolksPersona*) _tmp118_;
#line 143 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_tmp119_ = p;
#line 143 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp119_, TPF_TYPE_PERSONA)) {
#line 1067 "individual-properties.c"
								FolksPersona* _tmp120_ = NULL;
								TpfPersona* _tmp121_ = NULL;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								_tmp120_ = p;
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								_tmp121_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp120_, TPF_TYPE_PERSONA) ? ((TpfPersona*) _tmp120_) : NULL);
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								_g_object_unref0 (tpf_persona);
#line 145 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								tpf_persona = _tmp121_;
#line 146 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								_g_object_unref0 (p);
#line 146 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
								break;
#line 1082 "individual-properties.c"
							}
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (p);
#line 1086 "individual-properties.c"
						}
#line 141 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						_g_object_unref0 (_p_it);
#line 1090 "individual-properties.c"
					}
#line 149 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp122_ = tpf_persona;
#line 149 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp122_ != NULL, "tpf_persona != null");
#line 150 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp123_ = tpf_persona;
#line 150 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp124_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp123_, &_tmp124__length1);
#line 150 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp125_ = _tmp124_;
#line 150 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp125__length1 = _tmp124__length1;
#line 150 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_vala_string_array_contains (_tmp125_, _tmp125__length1, "alias"), "\"alias\" in tpf_persona.writeable_properties");
#line 152 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp126_ = tpf_persona;
#line 152 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp127_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp126_, &_tmp127__length1);
#line 152 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp128_ = _tmp127_;
#line 152 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp128__length1 = _tmp127__length1;
#line 152 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp128_, _tmp128__length1, "is-favourite"), "!(\"is-favourite\"                       in tpf_persona.writeable_properties)");
#line 154 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp129_ = tpf_persona;
#line 154 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp130_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp129_, &_tmp130__length1);
#line 154 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp131_ = _tmp130_;
#line 154 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp131__length1 = _tmp130__length1;
#line 154 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_vala_string_array_contains (_tmp131_, _tmp131__length1, "groups"), "\"groups\" in tpf_persona.writeable_properties");
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp132_ = tpf_persona;
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp133_ = folks_persona_get_is_user ((FolksPersona*) _tmp132_);
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp134_ = _tmp133_;
#line 156 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_tmp134_, "!tpf_persona.is_user");
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp135_ = tpf_persona;
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp136_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp135_, &_tmp136__length1);
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp137_ = _tmp136_;
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp137__length1 = _tmp136__length1;
#line 157 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp137_, _tmp137__length1, "birthday"), "!(\"birthday\" in tpf_persona.writeable_properties)");
#line 158 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp138_ = tpf_persona;
#line 158 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp139_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp138_, &_tmp139__length1);
#line 158 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp140_ = _tmp139_;
#line 158 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp140__length1 = _tmp139__length1;
#line 158 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp140_, _tmp140__length1, "email-addresses"), "!(\"email-addresses\" in tpf_persona.writeable_properties)");
#line 160 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp141_ = tpf_persona;
#line 160 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp142_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp141_, &_tmp142__length1);
#line 160 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp143_ = _tmp142_;
#line 160 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp143__length1 = _tmp142__length1;
#line 160 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp143_, _tmp143__length1, "full-name"), "!(\"full-name\" in tpf_persona.writeable_properties)");
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp144_ = tpf_persona;
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp145_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp144_, &_tmp145__length1);
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp146_ = _tmp145_;
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp146__length1 = _tmp145__length1;
#line 161 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp146_, _tmp146__length1, "phone-numbers"), "!(\"phone-numbers\" in tpf_persona.writeable_properties)");
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp147_ = tpf_persona;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp148_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp147_, &_tmp148__length1);
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp149_ = _tmp148_;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp149__length1 = _tmp148__length1;
#line 163 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp149_, _tmp149__length1, "urls"), "!(\"urls\" in tpf_persona.writeable_properties)");
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp150_ = i;
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp151_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp150_);
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp152_ = _tmp151_;
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp153_ = folks_phone_field_details_new ("+15142345678", NULL);
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp154_ = _tmp153_;
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp155_ = gee_collection_contains ((GeeCollection*) _tmp152_, _tmp154_);
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp155_, "new PhoneFieldDetails (\"+15142345678\")                       in i.phone_numbers");
#line 166 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp154_);
#line 168 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp156_ = i;
#line 168 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp157_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp156_);
#line 168 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp158_ = _tmp157_;
#line 168 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp158_, "Olivier Crete") == 0, "i.full_name == \"Olivier Crete\"");
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp159_ = i;
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp160_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp159_);
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp161_ = _tmp160_;
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp162_ = folks_email_field_details_new ("olivier@example.com", NULL);
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp163_ = _tmp162_;
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp164_ = gee_collection_contains ((GeeCollection*) _tmp161_, _tmp163_);
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp164_, "new EmailFieldDetails (\"olivier@example.com\")                       in i.email_addresses");
#line 169 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp163_);
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp165_ = i;
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp166_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp165_);
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp167_ = _tmp166_;
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp168_ = folks_url_field_details_new ("ocrete.example.com", NULL);
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp169_ = _tmp168_;
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp170_ = gee_collection_contains ((GeeCollection*) _tmp167_, _tmp169_);
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp170_, "new UrlFieldDetails (\"ocrete.example.com\") in i.urls");
#line 171 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp169_);
#line 125 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (tpf_persona);
#line 1242 "individual-properties.c"
				}
			}
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1247 "individual-properties.c"
		}
#line 75 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1251 "individual-properties.c"
	}
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp171_ = removed;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp172_ = gee_collection_get_size ((GeeCollection*) _tmp171_);
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp173_ = _tmp172_;
#line 175 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp173_ == 1, "removed.size == 1");
#line 1261 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp174_ = NULL;
		GeeIterator* _tmp175_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp174_ = removed;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp175_ = gee_iterable_iterator ((GeeIterable*) _tmp174_);
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp175_;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1274 "individual-properties.c"
			GeeIterator* _tmp176_ = NULL;
			gboolean _tmp177_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp178_ = NULL;
			gpointer _tmp179_ = NULL;
			FolksIndividual* _tmp180_ = NULL;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp176_ = _i_it;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp177_ = gee_iterator_next (_tmp176_);
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp177_) {
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1289 "individual-properties.c"
			}
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp178_ = _i_it;
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp179_ = gee_iterator_get (_tmp178_);
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp179_;
#line 179 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp180_ = i;
#line 179 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp180_ == NULL, "i == null");
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1303 "individual-properties.c"
		}
#line 177 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1307 "individual-properties.c"
	}
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 1313 "individual-properties.c"
}


static void ___lambda4__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	__lambda4_ ((IndividualPropertiesTests*) self, changes);
#line 1320 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties (IndividualPropertiesTests* self) {
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 66 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 66 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 69 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_dup ();
#line 69 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 70 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_object (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda4__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 182 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 182 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 187 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 190 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 190 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 64 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 1359 "individual-properties.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return _data1_;
#line 1368 "individual-properties.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1377 "individual-properties.c"
		IndividualPropertiesTests* self;
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		self = _data1_->self;
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block1Data, _data1_);
#line 1385 "individual-properties.c"
	}
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return _data2_;
#line 1395 "individual-properties.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1404 "individual-properties.c"
		IndividualPropertiesTests* self;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		self = _data2_->_data1_->self;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data2_->new_alias);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		block1_data_unref (_data2_->_data1_);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data2_->_data1_ = NULL;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block2Data, _data2_);
#line 1416 "individual-properties.c"
	}
}


static void ____lambda6_ (Block2Data* _data2_, GObject* s, GParamSpec* p) {
	Block1Data* _data1_;
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data1_ = _data2_->_data1_;
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data1_->self;
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 224 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 224 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 224 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 226 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 226 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp2_);
#line 226 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 226 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data2_->new_alias;
#line 226 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 227 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data1_->alias_notified = TRUE;
#line 1457 "individual-properties.c"
	}
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 1461 "individual-properties.c"
}


static void _____lambda6__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda6_ (self, _sender, pspec);
#line 1468 "individual-properties.c"
}


static void __lambda5_ (Block1Data* _data1_, GeeMultiMap* changes) {
	IndividualPropertiesTests* self;
	Block2Data* _data2_;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GeeSet* _tmp34_ = NULL;
	gint _tmp35_ = 0;
	gint _tmp36_ = 0;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data1_->self;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->_ref_count_ = 1;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->_data1_ = block1_data_ref (_data1_);
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 202 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 203 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 203 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 203 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 205 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = g_strdup ("New Alias");
#line 205 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data2_->new_alias = _tmp4_;
#line 1511 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = added;
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp6_;
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1524 "individual-properties.c"
			GeeIterator* _tmp7_ = NULL;
			gboolean _tmp8_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp9_ = NULL;
			gpointer _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			FolksIndividual* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			FolksIndividual* _tmp20_ = NULL;
			FolksPersona* persona = NULL;
			FolksPersona* _tmp31_ = NULL;
			FolksPersona* _tmp32_ = NULL;
			const gchar* _tmp33_ = NULL;
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = _i_it;
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp8_) {
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1552 "individual-properties.c"
			}
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = _i_it;
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp10_;
#line 209 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 209 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp11_ != NULL, "i != null");
#line 213 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = i;
#line 213 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 213 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp14_ = _tmp13_;
#line 213 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp15_ = self->priv->olivier_sha1;
#line 213 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (g_strcmp0 (_tmp14_, _tmp15_) != 0) {
#line 215 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (i);
#line 215 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				continue;
#line 1578 "individual-properties.c"
			}
#line 219 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp16_ = i;
#line 219 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp17_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp16_);
#line 219 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp18_ = _tmp17_;
#line 219 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp19_ = _data2_->new_alias;
#line 219 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (g_strcmp0 (_tmp18_, _tmp19_) != 0, "i.alias != new_alias");
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp20_ = i;
#line 221 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _tmp20_, "notify::alias", (GCallback) _____lambda6__g_object_notify, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 232 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			persona = NULL;
#line 1596 "individual-properties.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeSet* _tmp23_ = NULL;
				GeeIterator* _tmp24_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = i;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = _tmp22_;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_p_it = _tmp24_;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 1615 "individual-properties.c"
					GeeIterator* _tmp25_ = NULL;
					gboolean _tmp26_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp27_ = NULL;
					gpointer _tmp28_ = NULL;
					FolksPersona* _tmp29_ = NULL;
					FolksPersona* _tmp30_ = NULL;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp25_ = _p_it;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp26_ = gee_iterator_next (_tmp25_);
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (!_tmp26_) {
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						break;
#line 1631 "individual-properties.c"
					}
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp27_ = _p_it;
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					p = (FolksPersona*) _tmp28_;
#line 235 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp29_ = p;
#line 235 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp30_ = _g_object_ref0 (_tmp29_);
#line 235 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (persona);
#line 235 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					persona = _tmp30_;
#line 236 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (p);
#line 236 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					break;
#line 1651 "individual-properties.c"
				}
#line 233 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_p_it);
#line 1655 "individual-properties.c"
			}
#line 238 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp31_ = persona;
#line 238 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, TPF_TYPE_PERSONA), "persona is Tpf.Persona");
#line 243 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp32_ = persona;
#line 243 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp33_ = _data2_->new_alias;
#line 243 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			folks_alias_details_set_alias ((FolksAliasDetails*) G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, TPF_TYPE_PERSONA, TpfPersona), _tmp33_);
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (persona);
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1671 "individual-properties.c"
		}
#line 207 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1675 "individual-properties.c"
	}
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp34_ = removed;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp35_ = gee_collection_get_size ((GeeCollection*) _tmp34_);
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp36_ = _tmp35_;
#line 246 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp36_ == 1, "removed.size == 1");
#line 1685 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp37_ = NULL;
		GeeIterator* _tmp38_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp37_ = removed;
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp38_;
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1698 "individual-properties.c"
			GeeIterator* _tmp39_ = NULL;
			gboolean _tmp40_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp41_ = NULL;
			gpointer _tmp42_ = NULL;
			FolksIndividual* _tmp43_ = NULL;
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp39_ = _i_it;
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp40_ = gee_iterator_next (_tmp39_);
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp40_) {
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1713 "individual-properties.c"
			}
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp41_ = _i_it;
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp42_ = gee_iterator_get (_tmp41_);
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp42_;
#line 250 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp43_ = i;
#line 250 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp43_ == NULL, "i == null");
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1727 "individual-properties.c"
		}
#line 248 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1731 "individual-properties.c"
	}
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	block2_data_unref (_data2_);
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data2_ = NULL;
#line 1741 "individual-properties.c"
}


static void ___lambda5__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	__lambda5_ (self, changes);
#line 1748 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (IndividualPropertiesTests* self) {
	Block1Data* _data1_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data1_->_ref_count_ = 1;
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data1_->self = g_object_ref (self);
#line 195 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 195 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 196 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data1_->alias_notified = FALSE;
#line 199 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_dup ();
#line 199 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 200 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_data (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda5__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 253 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 258 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 260 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data1_->alias_notified, "alias_notified");
#line 263 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 263 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	block1_data_unref (_data1_);
#line 193 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data1_ = NULL;
#line 1802 "individual-properties.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return _data3_;
#line 1811 "individual-properties.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1820 "individual-properties.c"
		IndividualPropertiesTests* self;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		self = _data3_->self;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block3Data, _data3_);
#line 1828 "individual-properties.c"
	}
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return _data4_;
#line 1838 "individual-properties.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1847 "individual-properties.c"
		IndividualPropertiesTests* self;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		self = _data4_->_data3_->self;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data4_->new_alias);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		block3_data_unref (_data4_->_data3_);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data4_->_data3_ = NULL;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block4Data, _data4_);
#line 1859 "individual-properties.c"
	}
}


static void ____lambda8_ (Block4Data* _data4_, GObject* s, GParamSpec* p) {
	Block3Data* _data3_;
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data3_ = _data4_->_data3_;
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data3_->self;
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 297 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 297 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 297 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 299 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 299 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp2_);
#line 299 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 299 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data4_->new_alias;
#line 299 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 300 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data3_->alias_notified = TRUE;
#line 1900 "individual-properties.c"
	}
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 1904 "individual-properties.c"
}


static void _____lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda8_ (self, _sender, pspec);
#line 1911 "individual-properties.c"
}


static void __lambda7_ (Block3Data* _data3_, GeeMultiMap* changes) {
	IndividualPropertiesTests* self;
	Block4Data* _data4_;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GeeSet* _tmp49_ = NULL;
	gint _tmp50_ = 0;
	gint _tmp51_ = 0;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data3_->self;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->_ref_count_ = 1;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->_data3_ = block3_data_ref (_data3_);
#line 275 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 275 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 275 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 276 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 276 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 276 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 278 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = g_strdup ("New Alias");
#line 278 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data4_->new_alias = _tmp4_;
#line 1954 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = added;
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp6_;
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1967 "individual-properties.c"
			GeeIterator* _tmp7_ = NULL;
			gboolean _tmp8_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp9_ = NULL;
			gpointer _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			FolksIndividual* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			const gchar* _tmp19_ = NULL;
			FolksIndividual* _tmp20_ = NULL;
			FolksPersona* persona = NULL;
			FolksPersona* _tmp31_ = NULL;
			TpHandle handle = 0U;
			FolksPersona* _tmp32_ = NULL;
			TpContact* _tmp33_ = NULL;
			TpContact* _tmp34_ = NULL;
			guint _tmp35_ = 0U;
			guint _tmp36_ = 0U;
			TpTestsContactsConnection* conn = NULL;
			TpTestsBackend* _tmp37_ = NULL;
			void* _tmp38_ = NULL;
			TpTestsContactsConnection* _tmp39_ = NULL;
			TpTestsContactsConnection* _tmp40_ = NULL;
			TpTestsContactsConnection* _tmp41_ = NULL;
			TpHandle _tmp42_ = 0U;
			TpHandle* _tmp43_ = NULL;
			TpHandle* _tmp44_ = NULL;
			gint _tmp44__length1 = 0;
			const gchar* _tmp45_ = NULL;
			gchar* _tmp46_ = NULL;
			gchar** _tmp47_ = NULL;
			gchar** _tmp48_ = NULL;
			gint _tmp48__length1 = 0;
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = _i_it;
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp8_) {
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2014 "individual-properties.c"
			}
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = _i_it;
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp10_;
#line 282 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 282 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp11_ != NULL, "i != null");
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = i;
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp14_ = _tmp13_;
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp15_ = self->priv->olivier_sha1;
#line 286 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (g_strcmp0 (_tmp14_, _tmp15_) != 0) {
#line 288 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (i);
#line 288 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				continue;
#line 2040 "individual-properties.c"
			}
#line 292 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp16_ = i;
#line 292 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp17_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp16_);
#line 292 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp18_ = _tmp17_;
#line 292 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp19_ = _data4_->new_alias;
#line 292 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (g_strcmp0 (_tmp18_, _tmp19_) != 0, "i.alias != new_alias");
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp20_ = i;
#line 294 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _tmp20_, "notify::alias", (GCallback) _____lambda8__g_object_notify, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 305 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			persona = NULL;
#line 2058 "individual-properties.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeSet* _tmp23_ = NULL;
				GeeIterator* _tmp24_ = NULL;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = i;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = folks_individual_get_personas (_tmp21_);
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = _tmp22_;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_tmp24_ = gee_iterable_iterator ((GeeIterable*) _tmp23_);
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_p_it = _tmp24_;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 2077 "individual-properties.c"
					GeeIterator* _tmp25_ = NULL;
					gboolean _tmp26_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp27_ = NULL;
					gpointer _tmp28_ = NULL;
					FolksPersona* _tmp29_ = NULL;
					FolksPersona* _tmp30_ = NULL;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp25_ = _p_it;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp26_ = gee_iterator_next (_tmp25_);
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (!_tmp26_) {
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						break;
#line 2093 "individual-properties.c"
					}
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp27_ = _p_it;
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					p = (FolksPersona*) _tmp28_;
#line 308 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp29_ = p;
#line 308 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_tmp30_ = _g_object_ref0 (_tmp29_);
#line 308 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (persona);
#line 308 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					persona = _tmp30_;
#line 309 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (p);
#line 309 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					break;
#line 2113 "individual-properties.c"
				}
#line 306 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_p_it);
#line 2117 "individual-properties.c"
			}
#line 311 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp31_ = persona;
#line 311 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, TPF_TYPE_PERSONA), "persona is Tpf.Persona");
#line 315 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp32_ = persona;
#line 315 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp33_ = tpf_persona_get_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, TPF_TYPE_PERSONA, TpfPersona));
#line 315 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp34_ = _tmp33_;
#line 315 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp35_ = tp_contact_get_handle (_tmp34_);
#line 315 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp36_ = _tmp35_;
#line 315 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			handle = (TpHandle) _tmp36_;
#line 316 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp37_ = ((TpfTestTestCase*) self)->tp_backend;
#line 316 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp38_ = ((TpfTestTestCase*) self)->account_handle;
#line 316 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp39_ = tp_tests_backend_get_connection_for_handle (_tmp37_, _tmp38_);
#line 316 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp40_ = _g_object_ref0 (_tmp39_);
#line 316 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			conn = _tmp40_;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp41_ = conn;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp42_ = handle;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp43_ = g_new0 (TpHandle, 1);
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp43_[0] = _tmp42_;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp44_ = _tmp43_;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp44__length1 = 1;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp45_ = _data4_->new_alias;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp46_ = g_strdup (_tmp45_);
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp47_ = g_new0 (gchar*, 1 + 1);
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp47_[0] = _tmp46_;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp48_ = _tmp47_;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp48__length1 = 1;
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			tp_tests_contacts_connection_change_aliases (_tmp41_, (guint) 1, _tmp44_, _tmp48_);
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp48_ = (_vala_array_free (_tmp48_, _tmp48__length1, (GDestroyNotify) g_free), NULL);
#line 317 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp44_ = (g_free (_tmp44_), NULL);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (conn);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (persona);
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 2181 "individual-properties.c"
		}
#line 280 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 2185 "individual-properties.c"
	}
#line 320 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp49_ = removed;
#line 320 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp50_ = gee_collection_get_size ((GeeCollection*) _tmp49_);
#line 320 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp51_ = _tmp50_;
#line 320 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp51_ == 1, "removed.size == 1");
#line 2195 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp52_ = NULL;
		GeeIterator* _tmp53_ = NULL;
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp52_ = removed;
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp53_ = gee_iterable_iterator ((GeeIterable*) _tmp52_);
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp53_;
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 2208 "individual-properties.c"
			GeeIterator* _tmp54_ = NULL;
			gboolean _tmp55_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp56_ = NULL;
			gpointer _tmp57_ = NULL;
			FolksIndividual* _tmp58_ = NULL;
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp54_ = _i_it;
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp55_ = gee_iterator_next (_tmp54_);
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp55_) {
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2223 "individual-properties.c"
			}
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp56_ = _i_it;
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp57_ = gee_iterator_get (_tmp56_);
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp57_;
#line 324 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_tmp58_ = i;
#line 324 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp58_ == NULL, "i == null");
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 2237 "individual-properties.c"
		}
#line 322 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 2241 "individual-properties.c"
	}
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	block4_data_unref (_data4_);
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data4_ = NULL;
#line 2251 "individual-properties.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	__lambda7_ (self, changes);
#line 2258 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_alias_through_test_cm (IndividualPropertiesTests* self) {
	Block3Data* _data3_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data3_->_ref_count_ = 1;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data3_->self = g_object_ref (self);
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 268 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 269 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data3_->alias_notified = FALSE;
#line 272 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_dup ();
#line 272 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 273 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_data (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed_detailed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 327 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 327 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 332 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 334 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data3_->alias_notified, "alias_notified");
#line 337 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 337 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	block3_data_unref (_data3_);
#line 266 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data3_ = NULL;
#line 2312 "individual-properties.c"
}


static void __lambda9_ (IndividualPropertiesTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_ = NULL;
#line 351 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 353 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 353 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added (self, _tmp0_, NULL, NULL);
#line 2324 "individual-properties.c"
}


static void ___lambda9__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 351 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	__lambda9_ ((IndividualPropertiesTests*) self, changes);
#line 2331 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_contact_info (IndividualPropertiesTests* self) {
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	FolksIndividualAggregator* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	GeeHashSet* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
#line 340 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 342 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 342 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 343 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = self->priv->_changes_pending;
#line 343 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp1_, "birthday");
#line 344 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = self->priv->_changes_pending;
#line 344 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp2_, "email-addresses");
#line 345 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = self->priv->_changes_pending;
#line 345 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, "phone-numbers");
#line 346 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = self->priv->_changes_pending;
#line 346 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, "full-name");
#line 347 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = self->priv->_changes_pending;
#line 347 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, "urls");
#line 350 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = folks_individual_aggregator_dup ();
#line 350 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp6_;
#line 351 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp7_ = aggregator;
#line 351 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_object (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda9__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 356 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp8_ = aggregator;
#line 356 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp8_, NULL, NULL);
#line 361 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 363 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp9_ = self->priv->_changes_pending;
#line 363 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp10_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp9_);
#line 363 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp11_ = _tmp10_;
#line 363 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp11_ == 0, "this._changes_pending.size == 0");
#line 366 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 366 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 340 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 340 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 2406 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free (gpointer _data) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
	_data_ = _data;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->changes);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_slice_free (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData, _data_);
#line 2419 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added (IndividualPropertiesTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
	IndividualPropertiesTests* _tmp0_ = NULL;
	GeeMultiMap* _tmp1_ = NULL;
	GeeMultiMap* _tmp2_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_ = g_slice_new0 (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _individual_properties_tests_change_contact_info_aggregator_individuals_added);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->self = _tmp0_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = changes;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->changes);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->changes = _tmp2_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added_co (_data_);
#line 2448 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_finish (IndividualPropertiesTests* self, GAsyncResult* _res_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2456 "individual-properties.c"
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return _data5_;
#line 2465 "individual-properties.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 2474 "individual-properties.c"
		IndividualPropertiesTests* self;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		self = _data5_->self;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data5_->new_full_name);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data5_->new_url_fd);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data5_->new_phone_fd);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data5_->new_email_fd);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_date_time_unref0 (_data5_->new_birthday);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block5Data, _data5_);
#line 2492 "individual-properties.c"
	}
}


static void ____lambda10_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	FolksIndividual* _tmp4_ = NULL;
	GDateTime* _tmp5_ = NULL;
	GDateTime* _tmp6_ = NULL;
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 404 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 404 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 404 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = ind;
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp4_);
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = _tmp5_;
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_ != NULL) {
#line 2527 "individual-properties.c"
		GDateTime* _tmp7_ = NULL;
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = _data5_->new_birthday;
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp3_ = _tmp7_ != NULL;
#line 2533 "individual-properties.c"
	} else {
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp3_ = FALSE;
#line 2537 "individual-properties.c"
	}
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp3_) {
#line 2541 "individual-properties.c"
		FolksIndividual* _tmp8_ = NULL;
		GDateTime* _tmp9_ = NULL;
		GDateTime* _tmp10_ = NULL;
		GDateTime* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 407 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp8_ = ind;
#line 407 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp9_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp8_);
#line 407 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp10_ = _tmp9_;
#line 407 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp11_ = _data5_->new_birthday;
#line 407 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp12_ = g_date_time_equal (_tmp10_, _tmp11_);
#line 407 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp2_ = _tmp12_;
#line 2559 "individual-properties.c"
	} else {
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp2_ = FALSE;
#line 2563 "individual-properties.c"
	}
#line 406 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp2_) {
#line 2567 "individual-properties.c"
		GeeHashSet* _tmp13_ = NULL;
#line 409 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp13_ = self->priv->_changes_pending;
#line 409 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp13_, "birthday");
#line 2573 "individual-properties.c"
	}
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2577 "individual-properties.c"
}


static void _____lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda10_ (self, _sender, pspec);
#line 2584 "individual-properties.c"
}


static void ____lambda11_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	FolksEmailFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 416 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 416 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 416 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 418 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 418 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp2_);
#line 418 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 418 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_email_fd;
#line 418 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 418 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2622 "individual-properties.c"
		GeeHashSet* _tmp7_ = NULL;
#line 420 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 420 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "email-addresses");
#line 2628 "individual-properties.c"
	}
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2632 "individual-properties.c"
}


static void _____lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda11_ (self, _sender, pspec);
#line 2639 "individual-properties.c"
}


static void ____lambda12_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 427 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 427 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 427 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 429 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 429 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 429 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 429 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_full_name;
#line 429 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 2674 "individual-properties.c"
		GeeHashSet* _tmp6_ = NULL;
#line 430 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = self->priv->_changes_pending;
#line 430 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp6_, "full-name");
#line 2680 "individual-properties.c"
	}
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2684 "individual-properties.c"
}


static void _____lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda12_ (self, _sender, pspec);
#line 2691 "individual-properties.c"
}


static void ____lambda13_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	FolksPhoneFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 436 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 436 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 436 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 438 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 438 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp2_);
#line 438 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 438 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_phone_fd;
#line 438 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 438 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2729 "individual-properties.c"
		GeeHashSet* _tmp7_ = NULL;
#line 440 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 440 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "phone-numbers");
#line 2735 "individual-properties.c"
	}
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2739 "individual-properties.c"
}


static void _____lambda13__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda13_ (self, _sender, pspec);
#line 2746 "individual-properties.c"
}


static void ____lambda14_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests* self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	FolksUrlFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 447 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 447 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 447 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 449 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 449 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp2_);
#line 449 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 449 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_url_fd;
#line 449 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 449 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2784 "individual-properties.c"
		GeeHashSet* _tmp7_ = NULL;
#line 451 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 451 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "urls");
#line 2790 "individual-properties.c"
	}
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2794 "individual-properties.c"
}


static void _____lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	____lambda14_ (self, _sender, pspec);
#line 2801 "individual-properties.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static ((FolksAbstractFieldDetails*) v);
#line 465 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2810 "individual-properties.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static ((FolksAbstractFieldDetails*) a, (FolksAbstractFieldDetails*) b);
#line 465 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2819 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_ = _user_data_;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_source_object_ = source_object;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_res_ = _res_;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added_co (_data_);
#line 2833 "individual-properties.c"
}


static gboolean _individual_properties_tests_change_contact_info_aggregator_individuals_added_co (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_) {
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	switch (_data_->_state_) {
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		case 0:
#line 2842 "individual-properties.c"
		goto _state_0;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		case 1:
#line 2846 "individual-properties.c"
		goto _state_1;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		case 2:
#line 2850 "individual-properties.c"
		goto _state_2;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		case 3:
#line 2854 "individual-properties.c"
		goto _state_3;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		case 4:
#line 2858 "individual-properties.c"
		goto _state_4;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		case 5:
#line 2862 "individual-properties.c"
		goto _state_5;
		default:
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_assert_not_reached ();
#line 2867 "individual-properties.c"
	}
	_state_0:
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_ = g_slice_new0 (Block5Data);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->_ref_count_ = 1;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->self = g_object_ref (_data_->self);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->_async_data_ = _data_;
#line 372 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp0_ = NULL;
#line 372 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp0_ = _data_->changes;
#line 372 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp1_ = NULL;
#line 372 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp1_ = gee_multi_map_get_values (_data_->_tmp0_);
#line 372 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->added = _data_->_tmp1_;
#line 373 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp2_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp2_ = _data_->changes;
#line 373 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp3_ = NULL;
#line 373 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp3_ = gee_multi_map_get_keys (_data_->_tmp2_);
#line 373 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->removed = _data_->_tmp3_;
#line 375 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_get_current_time (&_data_->timeval);
#line 376 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_time_val_from_iso8601 ("1929-01-11T00:00:00Z", &_data_->timeval);
#line 377 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GTimeVal));
#line 377 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp4_ = _data_->timeval;
#line 377 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp5_ = NULL;
#line 377 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp5_ = g_date_time_new_from_timeval_utc (&_data_->_tmp4_);
#line 377 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_birthday = _data_->_tmp5_;
#line 378 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp6_ = NULL;
#line 378 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp6_ = _data_->_data5_->new_birthday;
#line 378 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data_->_tmp6_ != NULL, "new_birthday != null");
#line 379 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp7_ = NULL;
#line 379 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp7_ = folks_email_field_details_new ("cave@aperturescience.com", NULL);
#line 379 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_email_fd = _data_->_tmp7_;
#line 380 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp8_ = NULL;
#line 380 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp8_ = _data_->_data5_->new_email_fd;
#line 380 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp8_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_WORK);
#line 382 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp9_ = NULL;
#line 382 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp9_ = folks_phone_field_details_new ("+112233445566", NULL);
#line 382 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_phone_fd = _data_->_tmp9_;
#line 383 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp10_ = NULL;
#line 383 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp10_ = _data_->_data5_->new_phone_fd;
#line 383 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp10_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 385 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp11_ = NULL;
#line 385 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp11_ = folks_url_field_details_new ("aperturescience.com/cave", NULL);
#line 385 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_url_fd = _data_->_tmp11_;
#line 386 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp12_ = NULL;
#line 386 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp12_ = _data_->_data5_->new_url_fd;
#line 386 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp12_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_WORK);
#line 388 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp13_ = NULL;
#line 388 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp13_ = g_strdup ("Cave Johnson");
#line 388 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_full_name = _data_->_tmp13_;
#line 2960 "individual-properties.c"
	{
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp14_ = NULL;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp14_ = _data_->added;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp15_ = NULL;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp15_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp14_);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_i_it = _data_->_tmp15_;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp16_ = NULL;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp16_ = _data_->_i_it;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp17_ = FALSE;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp17_ = gee_iterator_next (_data_->_tmp16_);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp17_) {
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2986 "individual-properties.c"
			}
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp18_ = NULL;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp18_ = _data_->_i_it;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp19_ = NULL;
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp19_ = gee_iterator_get (_data_->_tmp18_);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->i = (FolksIndividual*) _data_->_tmp19_;
#line 392 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp20_ = NULL;
#line 392 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp20_ = _data_->i;
#line 392 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_data_->_tmp20_ != NULL, "i != null");
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp22_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp22_ = _data_->i;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp23_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp23_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp22_);
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp24_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp24_ = _data_->_tmp23_;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_tmp24_ == NULL) {
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp21_ = TRUE;
#line 3020 "individual-properties.c"
			} else {
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp25_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp25_ = _data_->_data5_->new_birthday;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp26_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp26_ = _data_->i;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp27_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp27_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp26_);
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp28_ = NULL;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp28_ = _data_->_tmp27_;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp29_ = FALSE;
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp29_ = g_date_time_equal (_data_->_tmp25_, _data_->_tmp28_);
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp21_ = !_data_->_tmp29_;
#line 3044 "individual-properties.c"
			}
#line 395 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_data_->_tmp21_, "i.birthday == null || !new_birthday.equal (i.birthday)");
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp30_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp30_ = _data_->i;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp31_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp31_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _data_->_tmp30_);
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp32_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp32_ = _data_->_tmp31_;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp33_ = NULL;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp33_ = _data_->_data5_->new_email_fd;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp34_ = FALSE;
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp34_ = gee_collection_contains ((GeeCollection*) _data_->_tmp32_, _data_->_tmp33_);
#line 396 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (!_data_->_tmp34_, "!(new_email_fd in i.email_addresses)");
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp35_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp35_ = _data_->_data5_->new_full_name;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp36_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp36_ = _data_->i;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp37_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp37_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp36_);
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp38_ = NULL;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp38_ = _data_->_tmp37_;
#line 397 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (g_strcmp0 (_data_->_tmp35_, _data_->_tmp38_) != 0, "new_full_name != i.full_name");
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp39_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp39_ = _data_->i;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp40_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp40_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _data_->_tmp39_);
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp41_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp41_ = _data_->_tmp40_;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp42_ = NULL;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp42_ = _data_->_data5_->new_phone_fd;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp43_ = FALSE;
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp43_ = gee_collection_contains ((GeeCollection*) _data_->_tmp41_, _data_->_tmp42_);
#line 398 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (!_data_->_tmp43_, "!(new_phone_fd in i.phone_numbers)");
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp44_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp44_ = _data_->i;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp45_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp45_ = folks_url_details_get_urls ((FolksUrlDetails*) _data_->_tmp44_);
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp46_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp46_ = _data_->_tmp45_;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp47_ = NULL;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp47_ = _data_->_data5_->new_url_fd;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp48_ = FALSE;
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp48_ = gee_collection_contains ((GeeCollection*) _data_->_tmp46_, _data_->_tmp47_);
#line 399 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (!_data_->_tmp48_, "!(new_url_fd in i.urls)");
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp49_ = NULL;
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp49_ = _data_->i;
#line 401 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp49_, "notify::birthday", (GCallback) _____lambda10__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp50_ = NULL;
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp50_ = _data_->i;
#line 413 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp50_, "notify::email-addresses", (GCallback) _____lambda11__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp51_ = NULL;
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp51_ = _data_->i;
#line 424 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp51_, "notify::full-name", (GCallback) _____lambda12__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp52_ = NULL;
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp52_ = _data_->i;
#line 433 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp52_, "notify::phone-numbers", (GCallback) _____lambda13__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp53_ = NULL;
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp53_ = _data_->i;
#line 444 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp53_, "notify::urls", (GCallback) _____lambda14__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 457 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->persona = NULL;
#line 3164 "individual-properties.c"
			{
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp54_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp54_ = _data_->i;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp55_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp55_ = folks_individual_get_personas (_data_->_tmp54_);
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp56_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp56_ = _data_->_tmp55_;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp57_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp57_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp56_);
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_p_it = _data_->_tmp57_;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp58_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp58_ = _data_->_p_it;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp59_ = FALSE;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp59_ = gee_iterator_next (_data_->_tmp58_);
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (!_data_->_tmp59_) {
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
						break;
#line 3198 "individual-properties.c"
					}
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp60_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp60_ = _data_->_p_it;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp61_ = NULL;
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp61_ = gee_iterator_get (_data_->_tmp60_);
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->p = (FolksPersona*) _data_->_tmp61_;
#line 460 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp62_ = NULL;
#line 460 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp62_ = _data_->p;
#line 460 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp63_ = NULL;
#line 460 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp63_ = _g_object_ref0 (_data_->_tmp62_);
#line 460 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 460 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->persona = _data_->_tmp63_;
#line 461 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->p);
#line 461 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					break;
#line 3226 "individual-properties.c"
				}
#line 458 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_p_it);
#line 3230 "individual-properties.c"
			}
#line 463 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp64_ = NULL;
#line 463 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp64_ = _data_->persona;
#line 463 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp64_, TPF_TYPE_PERSONA), "persona is Tpf.Persona");
#line 465 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp65_ = NULL;
#line 465 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp65_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 465 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->emails = _data_->_tmp65_;
#line 468 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp66_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp66_ = _data_->emails;
#line 468 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp67_ = NULL;
#line 468 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp67_ = _data_->_data5_->new_email_fd;
#line 468 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp66_, _data_->_tmp67_);
#line 469 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp68_ = NULL;
#line 469 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp68_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 469 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->phones = _data_->_tmp68_;
#line 472 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp69_ = NULL;
#line 472 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp69_ = _data_->phones;
#line 472 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp70_ = NULL;
#line 472 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp70_ = _data_->_data5_->new_phone_fd;
#line 472 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp69_, _data_->_tmp70_);
#line 473 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp71_ = NULL;
#line 473 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp71_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 473 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->urls = _data_->_tmp71_;
#line 476 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp72_ = NULL;
#line 476 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp72_ = _data_->urls;
#line 476 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp73_ = NULL;
#line 476 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp73_ = _data_->_data5_->new_url_fd;
#line 476 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp72_, _data_->_tmp73_);
#line 484 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->uncaught_errors = 0;
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp74_ = NULL;
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp74_ = _data_->i;
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp75_ = FALSE;
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp75_ = folks_individual_get_is_user (_data_->_tmp74_);
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp76_ = FALSE;
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp76_ = _data_->_tmp75_;
#line 486 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp76_) {
#line 487 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp77_ = 0;
#line 487 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp77_ = _data_->uncaught_errors;
#line 487 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp77_ + 1;
#line 3308 "individual-properties.c"
			}
			{
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp78_ = NULL;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp78_ = _data_->persona;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp79_ = NULL;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp79_ = _data_->_data5_->new_birthday;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 1;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_birthday_details_change_birthday ((FolksBirthdayDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp78_, TPF_TYPE_PERSONA, TpfPersona), _data_->_tmp79_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3325 "individual-properties.c"
				_state_1:
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_birthday_details_change_birthday_finish ((FolksBirthdayDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp78_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3333 "individual-properties.c"
						goto __catch0_folks_property_error;
					}
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 490 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3362 "individual-properties.c"
				}
			}
			goto __finally0;
			__catch0_folks_property_error:
			{
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e_birthday = _data_->_inner_error_;
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp80_ = NULL;
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp80_ = _data_->i;
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp81_ = FALSE;
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp81_ = folks_individual_get_is_user (_data_->_tmp80_);
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp82_ = FALSE;
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp82_ = _data_->_tmp81_;
#line 494 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp82_) {
#line 495 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp83_ = 0;
#line 495 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp83_ = _data_->uncaught_errors;
#line 495 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp83_ - 1;
#line 3392 "individual-properties.c"
				}
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e_birthday);
#line 3396 "individual-properties.c"
			}
			__finally0:
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 488 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3427 "individual-properties.c"
			}
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp84_ = NULL;
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp84_ = _data_->i;
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp85_ = FALSE;
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp85_ = folks_individual_get_is_user (_data_->_tmp84_);
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp86_ = FALSE;
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp86_ = _data_->_tmp85_;
#line 498 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp86_) {
#line 499 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp87_ = 0;
#line 499 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp87_ = _data_->uncaught_errors;
#line 499 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp87_ + 1;
#line 3449 "individual-properties.c"
			}
			{
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp88_ = NULL;
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp88_ = _data_->persona;
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp89_ = NULL;
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp89_ = _data_->emails;
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 2;
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_email_details_change_email_addresses ((FolksEmailDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp88_, TPF_TYPE_PERSONA, TpfPersona), (GeeSet*) _data_->_tmp89_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3466 "individual-properties.c"
				_state_2:
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_email_details_change_email_addresses_finish ((FolksEmailDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp88_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3474 "individual-properties.c"
						goto __catch1_folks_property_error;
					}
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 502 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3503 "individual-properties.c"
				}
			}
			goto __finally1;
			__catch1_folks_property_error:
			{
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e0 = _data_->_inner_error_;
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp90_ = NULL;
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp90_ = _data_->i;
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp91_ = FALSE;
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp91_ = folks_individual_get_is_user (_data_->_tmp90_);
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp92_ = FALSE;
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp92_ = _data_->_tmp91_;
#line 508 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp92_) {
#line 509 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp93_ = 0;
#line 509 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp93_ = _data_->uncaught_errors;
#line 509 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp93_ - 1;
#line 3533 "individual-properties.c"
				}
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e0);
#line 3537 "individual-properties.c"
			}
			__finally1:
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 500 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3568 "individual-properties.c"
			}
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp94_ = NULL;
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp94_ = _data_->i;
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp95_ = FALSE;
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp95_ = folks_individual_get_is_user (_data_->_tmp94_);
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp96_ = FALSE;
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp96_ = _data_->_tmp95_;
#line 512 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp96_) {
#line 513 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp97_ = 0;
#line 513 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp97_ = _data_->uncaught_errors;
#line 513 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp97_ + 1;
#line 3590 "individual-properties.c"
			}
			{
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp98_ = NULL;
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp98_ = _data_->persona;
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp99_ = NULL;
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp99_ = _data_->_data5_->new_full_name;
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 3;
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_name_details_change_full_name ((FolksNameDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp98_, TPF_TYPE_PERSONA, TpfPersona), _data_->_tmp99_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3607 "individual-properties.c"
				_state_3:
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_name_details_change_full_name_finish ((FolksNameDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp98_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3615 "individual-properties.c"
						goto __catch2_folks_property_error;
					}
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 516 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3644 "individual-properties.c"
				}
			}
			goto __finally2;
			__catch2_folks_property_error:
			{
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e1 = _data_->_inner_error_;
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp100_ = NULL;
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp100_ = _data_->i;
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp101_ = FALSE;
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp101_ = folks_individual_get_is_user (_data_->_tmp100_);
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp102_ = FALSE;
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp102_ = _data_->_tmp101_;
#line 520 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp102_) {
#line 521 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp103_ = 0;
#line 521 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp103_ = _data_->uncaught_errors;
#line 521 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp103_ - 1;
#line 3674 "individual-properties.c"
				}
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e1);
#line 3678 "individual-properties.c"
			}
			__finally2:
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 514 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3709 "individual-properties.c"
			}
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp104_ = NULL;
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp104_ = _data_->i;
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp105_ = FALSE;
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp105_ = folks_individual_get_is_user (_data_->_tmp104_);
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp106_ = FALSE;
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp106_ = _data_->_tmp105_;
#line 524 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp106_) {
#line 525 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp107_ = 0;
#line 525 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp107_ = _data_->uncaught_errors;
#line 525 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp107_ + 1;
#line 3731 "individual-properties.c"
			}
			{
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp108_ = NULL;
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp108_ = _data_->persona;
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp109_ = NULL;
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp109_ = _data_->phones;
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 4;
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_phone_details_change_phone_numbers ((FolksPhoneDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp108_, TPF_TYPE_PERSONA, TpfPersona), (GeeSet*) _data_->_tmp109_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3748 "individual-properties.c"
				_state_4:
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_phone_details_change_phone_numbers_finish ((FolksPhoneDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp108_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3756 "individual-properties.c"
						goto __catch3_folks_property_error;
					}
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 528 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3785 "individual-properties.c"
				}
			}
			goto __finally3;
			__catch3_folks_property_error:
			{
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e2 = _data_->_inner_error_;
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp110_ = NULL;
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp110_ = _data_->i;
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp111_ = FALSE;
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp111_ = folks_individual_get_is_user (_data_->_tmp110_);
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp112_ = FALSE;
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp112_ = _data_->_tmp111_;
#line 534 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp112_) {
#line 535 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp113_ = 0;
#line 535 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp113_ = _data_->uncaught_errors;
#line 535 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp113_ - 1;
#line 3815 "individual-properties.c"
				}
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e2);
#line 3819 "individual-properties.c"
			}
			__finally3:
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 526 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3850 "individual-properties.c"
			}
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp114_ = NULL;
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp114_ = _data_->i;
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp115_ = FALSE;
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp115_ = folks_individual_get_is_user (_data_->_tmp114_);
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp116_ = FALSE;
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp116_ = _data_->_tmp115_;
#line 538 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp116_) {
#line 539 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp117_ = 0;
#line 539 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp117_ = _data_->uncaught_errors;
#line 539 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp117_ + 1;
#line 3872 "individual-properties.c"
			}
			{
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp118_ = NULL;
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp118_ = _data_->persona;
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp119_ = NULL;
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp119_ = _data_->urls;
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 5;
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_url_details_change_urls ((FolksUrlDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp118_, TPF_TYPE_PERSONA, TpfPersona), (GeeSet*) _data_->_tmp119_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3889 "individual-properties.c"
				_state_5:
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				folks_url_details_change_urls_finish ((FolksUrlDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp118_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3897 "individual-properties.c"
						goto __catch4_folks_property_error;
					}
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 542 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3926 "individual-properties.c"
				}
			}
			goto __finally4;
			__catch4_folks_property_error:
			{
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->e3 = _data_->_inner_error_;
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp120_ = NULL;
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp120_ = _data_->i;
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp121_ = FALSE;
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp121_ = folks_individual_get_is_user (_data_->_tmp120_);
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp122_ = FALSE;
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp122_ = _data_->_tmp121_;
#line 548 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp122_) {
#line 549 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp123_ = 0;
#line 549 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp123_ = _data_->uncaught_errors;
#line 549 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp123_ - 1;
#line 3956 "individual-properties.c"
				}
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e3);
#line 3960 "individual-properties.c"
			}
			__finally4:
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 540 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3991 "individual-properties.c"
			}
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp124_ = NULL;
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp124_ = _data_->i;
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp125_ = FALSE;
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp125_ = folks_individual_get_is_user (_data_->_tmp124_);
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp126_ = FALSE;
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp126_ = _data_->_tmp125_;
#line 552 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp126_) {
#line 554 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp127_ = 0;
#line 554 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp127_ = _data_->uncaught_errors;
#line 554 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_data_->_tmp127_ == 0, "uncaught_errors == 0");
#line 4013 "individual-properties.c"
			}
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->urls);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->phones);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->emails);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->persona);
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->i);
#line 4025 "individual-properties.c"
		}
#line 390 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data_->_i_it);
#line 4029 "individual-properties.c"
	}
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp128_ = NULL;
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp128_ = _data_->removed;
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp129_ = 0;
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp129_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp128_);
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp130_ = 0;
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp130_ = _data_->_tmp129_;
#line 558 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data_->_tmp130_ == 1, "removed.size == 1");
#line 4045 "individual-properties.c"
	{
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp131_ = NULL;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp131_ = _data_->removed;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp132_ = NULL;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp132_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp131_);
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_data_->_r_it = _data_->_tmp132_;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp133_ = NULL;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp133_ = _data_->_r_it;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp134_ = FALSE;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp134_ = gee_iterator_next (_data_->_tmp133_);
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp134_) {
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
				break;
#line 4071 "individual-properties.c"
			}
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp135_ = NULL;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp135_ = _data_->_r_it;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp136_ = NULL;
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp136_ = gee_iterator_get (_data_->_tmp135_);
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->r = (FolksIndividual*) _data_->_tmp136_;
#line 562 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp137_ = NULL;
#line 562 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp137_ = _data_->r;
#line 562 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_data_->_tmp137_ == NULL, "r == null");
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->r);
#line 4091 "individual-properties.c"
		}
#line 560 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data_->_r_it);
#line 4095 "individual-properties.c"
	}
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->removed);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->added);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	block5_data_unref (_data_->_data5_);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_ = NULL;
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	if (_data_->_state_ == 0) {
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4109 "individual-properties.c"
	} else {
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4113 "individual-properties.c"
	}
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_object_unref (_data_->_async_result);
#line 369 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return FALSE;
#line 4119 "individual-properties.c"
}


static void individual_properties_tests_class_init (IndividualPropertiesTestsClass * klass) {
	gchar* _tmp0_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_parent_class = g_type_class_peek_parent (klass);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_type_class_add_private (klass, sizeof (IndividualPropertiesTestsPrivate));
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	((FolksTestCaseClass *) klass)->set_up = individual_properties_tests_real_set_up;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	((FolksTestCaseClass *) klass)->tear_down = individual_properties_tests_real_tear_down;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = individual_properties_tests_finalize;
#line 31 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_strdup ("telepathy:/org/freedesktop/Telepathy/Account/cm/protocol/account:");
#line 31 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_iid_prefix = _tmp0_;
#line 4139 "individual-properties.c"
}


static void individual_properties_tests_instance_init (IndividualPropertiesTests * self) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self->priv = INDIVIDUAL_PROPERTIES_TESTS_GET_PRIVATE (self);
#line 29 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = NULL;
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = individual_properties_tests_iid_prefix;
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = g_strconcat (_tmp0_, "olivier@example.com", NULL);
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = _tmp1_;
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = g_compute_checksum_for_string (G_CHECKSUM_SHA1, _tmp2_, (gsize) (-1));
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self->priv->olivier_sha1 = _tmp3_;
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_free0 (_tmp2_);
#line 4164 "individual-properties.c"
}


static void individual_properties_tests_finalize (GObject* obj) {
	IndividualPropertiesTests * self;
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTests);
#line 29 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 33 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_free0 (self->priv->olivier_sha1);
#line 27 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	G_OBJECT_CLASS (individual_properties_tests_parent_class)->finalize (obj);
#line 4178 "individual-properties.c"
}


GType individual_properties_tests_get_type (void) {
	static volatile gsize individual_properties_tests_type_id__volatile = 0;
	if (g_once_init_enter (&individual_properties_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (IndividualPropertiesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) individual_properties_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (IndividualPropertiesTests), 0, (GInstanceInitFunc) individual_properties_tests_instance_init, NULL };
		GType individual_properties_tests_type_id;
		individual_properties_tests_type_id = g_type_register_static (TPF_TEST_TYPE_TEST_CASE, "IndividualPropertiesTests", &g_define_type_info, 0);
		g_once_init_leave (&individual_properties_tests_type_id__volatile, individual_properties_tests_type_id);
	}
	return individual_properties_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	IndividualPropertiesTests* tests = NULL;
	IndividualPropertiesTests* _tmp0_ = NULL;
#line 569 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_test_init (&args_length1, &args, NULL);
#line 571 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = individual_properties_tests_new ();
#line 571 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	tests = _tmp0_;
#line 572 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 573 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	g_test_run ();
#line 574 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 576 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	result = 0;
#line 576 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (tests);
#line 576 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 4216 "individual-properties.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 567 "/opt/gnome3/source/folks/tests/telepathy/individual-properties.vala"
	return _vala_main (argv, argc);
#line 4226 "individual-properties.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



